pub fn incoming<S: Store>(
store: &S,
id: &RecordId,
kinds: &[RelationKind],
from: &[RecordKind],
) -> Result<Vec<Edge>>Expand description
Incoming edges of a record, optionally only from sources of some kinds.
pub fn incoming<S: Store>(
store: &S,
id: &RecordId,
kinds: &[RelationKind],
from: &[RecordKind],
) -> Result<Vec<Edge>>Incoming edges of a record, optionally only from sources of some kinds.